<?php // -*-mode: PHP; coding:utf-8;-*-

// This file contains PHP code that specifies language specific strings
// The default strings come from lang.en, and anything in a locale
// specific file will overwrite the default. This is a US/UK English file.
//
//
//
//
// This file is PHP code. Treat it as such.

// Used in style.inc
$vocab["mrbs"]               = "Rezervační systém";

// Used in functions.inc
$vocab["report"]             = "Výpis";
$vocab["admin"]              = "Administrátor";
$vocab["help"]               = "Nápověda";
$vocab["search"]             = "Hledat";
$vocab["outstanding"]        = "čekající na schválení";

// Used in index.php
$vocab["bookingsfor"]        = "Objednáno pro";
$vocab["bookingsforpost"]    = ""; // Goes after the date
$vocab["areas"]              = "Oblasti";
$vocab["daybefore"]          = "Den vzad";
$vocab["dayafter"]           = "Den vpřed";
$vocab["gototoday"]          = "Dnes";
$vocab["goto"]               = "Přejít na";
$vocab["nav_day"]            = "Den";
$vocab["nav_week"]           = "Týden";
$vocab["nav_month"]          = "Měsíc";
$vocab["highlight_line"]     = "Označte tuto řádku";
$vocab["click_to_reserve"]   = "Klepněte na buňku, abyste provedli rezervaci.";
$vocab["timezone"]           = "Časová zóna";
$vocab["weekbefore"]         = "Týden dozadu";
$vocab["weekafter"]          = "Týden dopředu";
$vocab["gotothisweek"]       = "Tento týden";
$vocab["monthbefore"]        = "Měsíc dozadu";
$vocab["monthafter"]         = "Měsic dopředu";
$vocab["gotothismonth"]      = "Tento měsíc";
$vocab["no_rooms_for_area"]  = "Pro tuto místnost/zdroj není definována žádná oblast!";

// Used in trailer.inc
$vocab["viewday"]            = "Dny";
$vocab["viewweek"]           = "Týdny";
$vocab["viewmonth"]          = "Měsíce ";
$vocab["ppreview"]           = "Pro tisk";

// Used in edit_entry.php
$vocab["addentry"]           = "Přidat záznam";
$vocab["editentry"]          = "Editovat záznam";
$vocab["copyentry"]          = "Kopírovat záznam";
$vocab["editseries"]         = "Editovat sérii";
$vocab["copyseries"]         = "Kopírovat sérii";
$vocab["namebooker"]         = "Název události (např. Prezentace systému LNX)";
$vocab["fulldescription"]    = "Popis události";
$vocab["date"]               = "Datum";
$vocab["start"]              = "Začátek";
$vocab["end"]                = "Konec";
$vocab["start_date"]         = "Čas začátku";
$vocab["end_date"]           = "Čas konce";
$vocab["time"]               = "Čas";
$vocab["period"]             = "Perioda";
$vocab["duration"]           = "Doba trvání";
$vocab["second_lc"]          = "sekunda";
$vocab["seconds"]            = "sekundy";
$vocab["minute_lc"]          = "minuta";
$vocab["minutes"]            = "minuty";
$vocab["hour_lc"]            = "hodina";
$vocab["hours"]              = "hodiny";
$vocab["day"]                = "den";
$vocab["days"]               = "dny";
$vocab["week"]               = "týden";
$vocab["weeks"]              = "týdny";
$vocab["year_lc"]            = "rok";
$vocab["years"]              = "roky";
$vocab["period_lc"]          = "perioda";
$vocab["periods"]            = "periody";
$vocab["all_day"]            = "Celý den";
$vocab["area"]               = "Oblast";
$vocab["type"]               = "Typ";
$vocab["save"]               = "Uložit";
$vocab["rep_type"]           = "Typ opakování";
$vocab["rep_type_0"]         = "Žádný";
$vocab["rep_type_1"]         = "Denně";
$vocab["rep_type_2"]         = "Týdně";
$vocab["rep_type_3"]         = "Měsíčně";
$vocab["rep_type_4"]         = "Ročně";
$vocab["ord_1"]              = "první";
$vocab["ord_2"]              = "druhé";
$vocab["ord_3"]              = "třetí";
$vocab["ord_4"]              = "čtvrté";
$vocab["ord_5"]              = "páté";
$vocab["ord_-1"]             = "poslední";
$vocab["ord_-2"]             = "druhé od konce";
$vocab["ord_-3"]             = "třetí od konce";
$vocab["ord_-4"]             = "čtvrté od konce";
$vocab["ord_-5"]             = "páté od konce";
$vocab["rep_end_date"]       = "Datum konce opakování";
$vocab["rep_rep_day"]        = "Den opakování";
$vocab["rep_interval"]       = "Opakovat každé";
$vocab["month_absolute"]     = "Den";
$vocab["month_relative"]     = "V";
$vocab["skip_conflicts"]     = "Vynechat předchozí konflikty";
$vocab["ctrl_click"]         = "Použijte Ctrl + kliknutí pro výběr více místností";
$vocab["entryid"]            = "ID záznamu";
$vocab["repeat_id"]          = "ID opakování"; 
$vocab["brief_description"]  = "Krátký popis.";
$vocab["status"]             = "Stav";
$vocab["public"]             = "Veřejný";
$vocab["private"]            = "Soukromý";
$vocab["unavailable"]        = "[Soukromý]";
$vocab["is_mandatory_field"] = "je povinné pole, prosím doplňte hodnotu";
$vocab["missing_mandatory_field"] = "Nevyplnili jste povinné pole";
$vocab["confirmed"]          = "Potvrzeno";
$vocab["start_after_end"]    = "Den začátku po dni konce";
$vocab["start_after_end_long"] = "Chyba: den začátku je po dni konce";

// Used in view_entry.php
$vocab["description"]         = "Popis";
$vocab["room"]                = "Místnost";
$vocab["createdby"]           = "Vytvořeno";
$vocab["lastupdate"]          = "Naposled změněno";
$vocab["repeat_on"]           = "Den opakování";
$vocab["deleteentry"]         = "Smaž záznam";
$vocab["deleteseries"]        = "Smaž série";
$vocab["exportentry"]         = "Exportuj záznam";
$vocab["exportseries"]        = "Exportuj série";
$vocab["confirmdel"]          = "Jste si opravdu jistý smazáním tohoto záznamu?";
$vocab["returnprev"]          = "Návrat na předchozí stránku";
$vocab["invalid_entry_id"]    = "Špatné ID záznamu.";
$vocab["invalid_series_id"]   = "Špatné ID série.";
$vocab["confirmation_status"] = "Stav potvrzení";
$vocab["tentative"]           = "Nezávazný";
$vocab["approval_status"]     = "Stav schválení";
$vocab["approved"]            = "Schváleno";
$vocab["awaiting_approval"]   = "Očekává schválení";
$vocab["approve"]             = "Schválit";
$vocab["reject"]              = "Odmítnout";
$vocab["more_info"]           = "Další info";
$vocab["remind_admin"]        = "Připomeň se administrátorovi";
$vocab["series"]              = "Série";
$vocab["request_more_info"]   = "Prosim uveďte další informace";
$vocab["reject_reason"]       = "Prosím vložte důvod odmítnutí tohoto požadavku na rezervaci";
$vocab["send"]                = "Odeslat";
$vocab["approve_failed"]      = "Nebylo možno schválit rezervaci.";
$vocab["no_request_yet"]      = "Žádné požadavky ještě nebyly odeslány"; // Used for the title tooltip on More Info button
$vocab["last_request"]        = "Poslední požadavek odeslán";         // Used for the title tooltip on More Info button
$vocab["by"]                  = "kým";                           // Used for the title tooltip on More Info button
$vocab["sent_at"]             = "Odesláno ";
$vocab["yes"]                 = "Ano";
$vocab["no"]                  = "Ne";

// Used in edit_entry_handler.php
$vocab["error"]              = "Chyba";
$vocab["sched_conflict"]     = "Konflikt při plánování";
$vocab["conflict"]           = "Nová rezervace bude kolidovat s těmito záznamy";
$vocab["no_conflicts"]       = "Žádná kolize v plánování";
$vocab["rules_broken"]       = "Nová bude kolidovat s těmito zásadami";
$vocab["no_rules_broken"]    = "Žádná kolize se zásadami";
$vocab["schedule"]           = "Plánování";
$vocab["policy"]             = "Zásady";
$vocab["too_many_entries"]   = "Vybraná volba byla vytvořena pro jiné záznamy.<br>Prosím vyberte jinou volbu!";
$vocab["returncal"]          = "Návrat do kalendáře";
$vocab["failed_to_acquire"]  = "Chyba při zajišťování výhradního přístupu k databázi";
$vocab["invalid_booking"]    = "Neplatná rezervace";
$vocab["must_set_description"] = "Musíte uvést krátký popis rezervace. Prosím jděte zpět a vložte jej.";
$vocab["no_rooms_selected"]    = "Musíte vybrat místnost.";
$vocab["mail_subject_approved"]  = "Záznam schválen pro %s MRBS"; // $mrbs_company
$vocab["mail_subject_rejected"]  = "Záznam odmítnut pro %s MRBS"; // $mrbs_company
$vocab["mail_subject_more_info"] = "%s MRBS: je vyžadováno více informací"; // $mrbs_company
$vocab["mail_subject_reminder"]  = "Připomenutí pro %s MRBS"; // $mrbs_company
$vocab["mail_body_approved"]     = "Záznam byl schválen administrátorem; zde jsou detaily:";
$vocab["mail_body_rej_entry"]    = "Záznam byl odmítnut administrátorem, zde jsou detaily:";
$vocab["mail_body_more_info"]    = "Administrátor požaduje více informací o rezervaci; zde jsou detaily:";
$vocab["mail_body_reminder"]     = "Připomenutí - záznam čeká na schválení; zde jsou detaily:";
$vocab["mail_body_repeats_booked"]   = "Následující datum bylo rezervováno:";
$vocab["mail_body_repeats_deleted"]  = "Následující rezervace byla smazána:";
$vocab["mail_body_exceptions"]       = "Následující data nemohou být rezervována z důvodu konfliktu:";
$vocab["mail_subject_new_entry"]     = "Záznam přidán pro %s MRBS"; // $mrbs_company
$vocab["mail_subject_changed_entry"] = "Záznam změněn pro %s MRBS"; // $mrbs_company
$vocab["mail_subject_delete"]        = "Záznam smazán pro %s MRBS"; // $mrbs_company
$vocab["mail_body_new_entry"]     = "Byl vytvořen nový záznam, zde jsou detaily:";
$vocab["mail_body_changed_entry"] = "Záznam byl změněn, zde jsou detaily:";
$vocab["mail_body_del_entry"]     = "Záznam byl smazán, zde jsou detaily";
$vocab["new_value"]           = "Nový";
$vocab["old_value"]           = "Starý";
$vocab["reason"]              = "Důvod";
$vocab["info_requested"]      = "Požadavek na uvedení více informací";
$vocab["min_time_before"]     = "Nejmenší interval mezi aktuálním časem a začátkem rezervace je";
$vocab["max_time_before"]     = "Největší interval mezi aktuálním časem a začátkem rezervace je";
$vocab["latest_booking_date"]     = "Poslední datum rezervace je %s";
$vocab["max_booking_duration"]    = "Maximální doba trvání rezervace je";
$vocab["max_per_day_global"]      = "Maximální počet rezervací na den na jednoho uživatele v celém systému je";
$vocab["max_per_week_global"]     = "Maximální počet rezervací týdně na jednoho uživatele v celém systému je";
$vocab["max_per_month_global"]    = "Maximální počet rezervací za měsíc na jednoho uživatele v celém systému je";
$vocab["max_per_year_global"]     = "Maximální počet rezervací za rok na jednoho uživatele v celém systému je";
$vocab["max_per_future_global"]   = "Maximální počet nevyřízených rezervací na uživatele v rámci celého systému je";
$vocab["max_per_day_area"]        = "Maximální počet rezervací na den na jednoho uživatele v této oblasti je";
$vocab["max_per_week_area"]       = "Maximální počet rezervací týdně na jednoho uživatele v této oblasti je";
$vocab["max_per_month_area"]      = "Maximální počet rezervací za měsíc na jednoho uživatele v této oblasti je";
$vocab["max_per_year_area"]       = "Maximální počet rezervací za rok na jednoho uživatele v této oblasti je";
$vocab["max_per_future_area"]     = "Maximální počet nevyřízených rezervací na uživatele v této oblasti je";
$vocab["skip_and_book"]           = "Vynechat a zarezerovat";
$vocab["skip_and_book_note"]      = "Pokračovat v rezervaci, vynechat kolidující položky";

// Used in pending.php
$vocab["pending"]            = "Rezervace čekající na schválení";
$vocab["none_outstanding"]   = "Žádné vaše rezervace nečekají na schválení.";

// Authentication stuff
$vocab["accessdenied"]       = "Přístup zamítnut";
$vocab["norights"]           = "Nemáte přístupové právo pro změnu této položky.";
$vocab["please_login"]       = "Prosím, přihlašte se";
$vocab["users.name"]         = "Jméno";
$vocab["users.password"]     = "Heslo";
$vocab["users.level"]        = "Práva";
$vocab["unknown_user"]       = "Neznámý uživatel";
$vocab["login"]              = "Přihlásit se";
$vocab["logoff"]             = "Odhlásit se";
$vocab["username_or_email"]  = "Uživatelské jméno nebo email";

// Database upgrade code
$vocab["database_login"]           = "Přihlašovací jméno pro databázi";
$vocab["upgrade_required"]         = "Je třeba provést upgrade databáze. Prosím zazálohujte databázi.";
$vocab["supply_userpass"]          = "Prosím vyplňte jméno a heslo k databázi (musí mít administrátorská práva).";
$vocab["contact_admin"]            = "Jestliže nejste administrátor rezervačního systému, prosím kontaktujte %s."; // $mrbs_admin
$vocab["upgrade_to_version"]       = "Upgrade databáze na verzi";
$vocab["upgrade_to_local_version"] = "Upgrade databáze na lokánlní verzi";
$vocab["upgrade_completed"]        = "Upgrade databáze dokončena.";

// User access levels
$vocab["level_0"]            = "žádný";
$vocab["level_1"]            = "uživatel";
$vocab["level_2"]            = "administátor";
$vocab["level_3"]            = "administrátor uživatelů";

// Authentication database
$vocab["user_list"]          = "Seznam uživatelů";
$vocab["edit_user"]          = "Editovat uživatele";
$vocab["delete_user"]        = "Smazat tohoto uživatele";
//$vocab["users.name"]         = Use the same as above, for consistency.
//$vocab["users.password"]     = Use the same as above, for consistency.
$vocab["users.email"]        = "E-mailová adresa";
$vocab["password_twice"]     = "Pokud chcete změnit heslo, prosím napište ho dvakrát";
$vocab["passwords_not_eq"]   = "Chyba: Vložená hesla se neshodují.";
$vocab["password_invalid"]   = "Heslo nesplňuje bezpečnostní požadavky. Musí obsahovat alespoň:";
$vocab["policy_length"]      = "%d znaků(s)";
$vocab["policy_alpha"]       = "%d písmen";
$vocab["policy_lower"]       = "%d malých písmen";
$vocab["policy_upper"]       = "%d velkých písmen";
$vocab["policy_numeric"]     = "%d číselných znaků";
$vocab["policy_special"]     = "%d speciálních znaků";
$vocab["add_new_user"]       = "Přidat nového uživatele";
$vocab["action"]             = "Akce";
$vocab["user"]               = "Uživatel";
$vocab["administrator"]      = "Administrátor";
$vocab["unknown"]            = "Neznámý";
$vocab["ok"]                 = "OK";
$vocab["show_my_entries"]    = "Klikněte zde pro zobrazení všech nadcházejících záznamů";
$vocab["no_users_initial"]   = "V databázi nejsou žádní uživatelé, povolte vytvoření prvního uživatele";
$vocab["no_users_create_first_admin"] = "Vytvořte uživatele pro administrátora, pak se můžete přihlásit a vytvářet nové uživatele.";
$vocab["warning_last_admin"] = "Varování! Tohle je poslední administrátorstký účet takže jej nemůžete smazat ani mu odebrat administrátorská práva, v opačném případě vám bude zablokován přístup do systému.";

// Used in search.php
$vocab["invalid_search"]     = "Prázdný nebo neplatný hledaný řetězec.";
$vocab["search_results"]     = "Výsledek hledání pro";
$vocab["nothing_found"]      = "Nic nenalezeno";
$vocab["records"]            = "Záznam";
$vocab["through"]            = " skrze ";
$vocab["of"]                 = " o ";
$vocab["previous"]           = "Předchozi";
$vocab["next"]               = "Další";
$vocab["entry"]              = "Záznam";
$vocab["search_button"]      = "Hledat";
$vocab["search_for"]         = "Hledat co";
$vocab["from"]               = "Od";

// Used in report.php
$vocab["report_on"]             = "Výpis schůzek";
$vocab["report_start"]          = "Výpis začátků";
$vocab["report_end"]            = "Výpis konců";
$vocab["match_area"]            = "Hledaná oblast";
$vocab["match_room"]            = "Hledaná místnost/zdroj";
$vocab["match_type"]            = "Hledaný typ";
$vocab["ctrl_click_type"]       = "Použijte ctrl + kliknutí pro vybrání více typů";
$vocab["match_entry"]           = "Hledat v krátkém popisu";
$vocab["match_descr"]           = "Hledat v celém popisu";
$vocab["output"]                = "Výstup";
$vocab["summary"]               = "Přehled";
$vocab["format"]                = "Formát";
$vocab["html"]                  = "HTML";
$vocab["csv"]                   = "CSV";
$vocab["ical"]                  = "iCalendar (.ics soubor) - bez doby trvání";
$vocab["combination_not_supported"] = "Tento výstup není podporován v tomto formátu";
$vocab["summarize_by"]          = "Přehled od";
$vocab["sum_by_descrip"]        = "Krátký popis";
$vocab["sum_by_creator"]        = "Tvůrce";
$vocab["sum_by_type"]           = "Typ";
$vocab["entry_found"]           = "nalezeno";
$vocab["entries_found"]         = "nalezenond";
$vocab["summary_header"]        = "Přehled (záznamy) hodin";
$vocab["summary_header_per"]    = "Přehled (záznamy) period";
$vocab["summary_header_both"]   = "Přehled (záznamy) hodin/period";
$vocab["entries"]               = "záznamy";
$vocab["total"]                 = "Celkem";
$vocab["submitquery"]           = "Spustit výpis";
$vocab["sort_rep"]              = "Seřadit výpis dle";
$vocab["sort_rep_time"]         = "Počáteční datum/čas";
$vocab["sort_room"]             = "Místnost";
$vocab["fulldescription_short"] = "Celkový popis";
$vocab["both"]                  = "Vše";
$vocab["privacy_status"]        = "Soukromý status";
$vocab["search_criteria"]       = "Kritéria pro hledání";
$vocab["presentation_options"]  = "Možnosti výstupu";
$vocab["delete_entries"]        = "Odstranění položek";
$vocab["delete_entries_warning"] = "UPOZORNĚNÍ! Vymaže všechny položky odpovídající " .
                                   "danému hledanému řetězci. Tuto operaci nelze vrátit zpět. Opravdu " .
                                   "chcete pokračovat?\n\n" .
                                   "Celkový počet položek, které budou smazány: %%s"; // The % sign is escaped because the string substitution is done by JavaScript
$vocab["delete_entries_failed"] = "Položky nemohou být odstraněny.";

// Used in admin.php
$vocab["edit"]               = "Upravit";
$vocab["delete"]             = "Smazat";
$vocab["rooms"]              = "Místnost";
$vocab["in"]                 = "v";
$vocab["noareas"]            = "Žádné oblasti nebyly definovány.";
$vocab["noareas_enabled"]    = "Žádné oblasti nebyly povoleny.";
$vocab["addarea"]            = "Přidat oblast";
$vocab["name"]               = "Jméno";
$vocab["noarea"]             = "Není vybrána žádná oblast";
$vocab["browserlang"]        = "Tvůj webový prohlížeč má nastaveno následující pořadí preferování jazyků";
$vocab["addroom"]            = "Přidat místnost/zdroj";
$vocab["capacity"]           = "Kapacita";
$vocab["norooms"]            = "Žádné místnosti/zdroje nebyly definovány.";
$vocab["norooms_enabled"]    = "Žádné místnosti/zdroje nebyly povoleny.";
$vocab["administration"]     = "Detaily místnosti/zdroje";
$vocab["invalid_area_name"]  = "Toto jméno oblasti je již použito!";
$vocab["empty_name"]         = "Nevložili jste jméno!";

// Used in edit_area.php and/or edit_room.php
$vocab["editarea"]                = "Upravit oblast";
$vocab["change"]                  = "Změnit";
$vocab["editroom"]                = "Upravit místnost/zdroj";
$vocab["viewroom"]                = "Zobrazit místnost/zdroj";
$vocab["not_found"]               = " nenalezeno";
$vocab["room_admin_email"]        = "E-mail administrátora místnosti/zdroje";
$vocab["area_admin_email"]        = "E-mail administrátora oblasti";
$vocab["area_first_slot_start"]   = "Začátek první pozice";
$vocab["area_last_slot_start"]    = "Začátek poslední pozice";
$vocab["area_res_mins"]           = "Rozlišení (minuty)";
$vocab["area_def_duration_mins"]  = "Výchozí délka trvání (minuty)";
$vocab["invalid_area"]            = "Neplatná oblast!";
$vocab["invalid_room_name"]       = "Toto jméno místnosti/zdroje již bylo použito v aktuální oblasti!";
$vocab["invalid_email"]           = "Neplatná emailová adresa!";
$vocab["invalid_resolution"]      = "Neplatná kombinace první pozice, poslední pozice a rozlišení!";
$vocab["general_settings"]        = "Obecné";
$vocab["time_settings"]           = "Časy pozic";
$vocab["confirmation_settings"]   = "Nastavení potvrzování";
$vocab["allow_confirmation"]      = "Povolit nezávazné rezervace";
$vocab["default_settings_conf"]   = "Výchozí nastavení";
$vocab["default_confirmed"]       = "Potvrzeno";
$vocab["default_tentative"]       = "Nezávazné";
$vocab["approval_settings"]       = "Nastavené schvalování";
$vocab["enable_approval"]         = "Je třeba schválit rezervaci";
$vocab["enable_reminders"]        = "Povolit uživatelům připomínání administrátorům";
$vocab["private_settings"]        = "Nastavení soukromí";
$vocab["allow_private"]           = "Povolit soukromé rezervace";
$vocab["force_private"]           = "Vynutit soukromé rezervace";
$vocab["default_settings"]        = "Výchozí/vynucená nastavení";
$vocab["default_private"]         = "Soukromá";
$vocab["default_public"]          = "Veřejná";
$vocab["private_display"]         = "Nastavení soukromí (zobrazení)";
$vocab["private_display_label"]   = "Jak by měly být zobrazeny soukromé rezervace?";
$vocab["private_display_caution"] = "UPOZORNĚNÍ: pořádně se rozmyslete předtím než v tomto nastavení něco změníte!";
$vocab["treat_respect"]           = "Respektuj nastavení soukromí této rezervace";
$vocab["treat_private"]           = "Považuj všechny rezervace za soukromé, ignoruj jejich výchozí nastavení soukromí";
$vocab["treat_public"]            = "Považuj všechny rezervace za veřejné, ignoruj jejich výchozí nastavení soukromí";
$vocab["sort_key"]                = "Klíč pro řazení";
$vocab["sort_key_note"]           = "Toto je klíč použitý pro řazení místností/zdrojů";
$vocab["booking_policies"]        = "Zásady rezerování";
$vocab["min_book_ahead"]          = "Rozšířené rezervace - minimum";
$vocab["max_book_ahead"]          = "Rozšířené rezervace - maximum";
$vocab["this_area"]               = "Tato oblast";
$vocab["whole_system"]            = "Celý systém";
$vocab["whole_system_note"]       = "Hodnoty pro celý systém jsou nastaveny v konfiguračním souboru";
$vocab["max_per_day"]             = "Maximální počet za den";
$vocab["max_per_week"]            = "Maximální počet za týden";
$vocab["max_per_month"]           = "Maximální počet za měsíc";
$vocab["max_per_year"]            = "Maximální počet za rok";
$vocab["max_per_future"]          = "Maximální počet v budoucnu";
$vocab["custom_html"]             = "Libovolné HTML";
$vocab["custom_html_note"]        = "Toto pole může být použito pro zobrazení vašeho vlastního HTML, například vložená Google mapa";
$vocab["email_list_note"]         = "Vložte seznam e-mailových adres oddělených čárkami nebo novými řádky";
$vocab["mode"]                    = "Mód";
$vocab["mode_periods"]            = "Periody";
$vocab["mode_times"]              = "Časy";
$vocab["times_only"]              = "pouze časový mód";
$vocab["enabled"]                 = "Povoleno";
$vocab["disabled"]                = "Zakázáno";
$vocab["disabled_area_note"]      = "Pokud je tato oblast zakázána, nezobrazí se v pohledu na kalendář " .
                                    "a nebude možno zarezervovat místnosti v ní. Existující rezervace " .
                                    "budou zachovány a zůstanou viditelné ve výsledích hledání a ve výpisech.";
$vocab["disabled_room_note"]      = "Tato místnost je zakázána, nezobrazí se v pohledu na kalendář " .
                                    "a nebude možno ji zarezervovat. Existující rezervace " .
                                    "budou zachovány a zůstanou viditelné ve výsledích hledání a ve výpisech.";
$vocab["book_ahead_note_periods"] = "Při použití období je rezervace zaokrouhlena dolů na nejbližší celý den.";

// Used in edit_users.php
$vocab["name_empty"]         = "Musíte vložit jméno.";
$vocab["name_not_unique"]    = "již existuje. Prosím vyberte jiné jméno.";

// Used in del.php
$vocab["deletefollowing"]    = "Budou smazány následující rezervace";
$vocab["sure"]               = "Jste si jistí?";
$vocab["YES"]                = "ANO";
$vocab["NO"]                 = "NE";
$vocab["delarea"]            = "Musíte smazat všechny místnosti v této oblasti před smazáním<p>";

// Used in help.php
$vocab["about_mrbs"]         = "O rezervačním systému";
$vocab["database"]           = "Databáze";
$vocab["system"]             = "Systém";
$vocab["servertime"]         = "Čas serveru";
$vocab["please_contact"]     = "Prosím kontaktujte %s pro všechny otázky, které zde nejsou zodpovězeny.";

// Used in import.php
$vocab["import_icalendar"]            = "Import iCalendar souboru";
$vocab["area_room_settings"]          = "Oblasti a místnosti";
$vocab["other_settings"]              = "Další nastavení";
$vocab["import_intro"]                = "Tento formulář umožňuje naimportovat iCalendar soubor " .
                                        "vyhovující RFC 5545 do MRBS. Jen ty opakující se události, " .
                                        "které mají nastavené pravidlo v souladu  s opakovacím typem " .
                                        "budou do MRBS naimportovány.";
$vocab["file_name"]                   = "Soubor";
$vocab["import"]                      = "Import";
$vocab["upload_failed"]               = "Načtení se nezdařilo";
$vocab["max_allowed_file_size"]       = "Maximální povolená velikost souboru je %s";
$vocab["no_file"]                     = "Žádný soubor nenačten";
$vocab["badly_formed_ics"]            = "Špatné formátování VCALENDAR souboru";
$vocab["area_room_order"]             = "Řazení";
$vocab["area_room_order_note"]        = "Řazení jmen oblastí a místností ve vlastnostech lokalit";
$vocab["area_room"]                   = "Oblast-Místnost";
$vocab["room_area"]                   = "Místnost-Oblast";
$vocab["area_room_delimiter"]         = "Oddělovač";
$vocab["area_room_delimiter_note"]    = "Řetězec oddělující jméno oblasti a místnosti ve vlastnostech lokalit.  " .
                                        "Není-li oddělovač nalezen MRBS se podívá na unikátní místnost se stejným " .
                                        "jménem jako lokalita";
$vocab["area_room_create"]            = "Vytvořte místnosti v případě potřeby";
$vocab["default_type"]                = "Výchozí typ";
$vocab["room_does_not_exist_no_area"] = "místnost neexistuje a nemůže být přidána - není zadaná oblast";
$vocab["room_not_unique_no_area"]     = "jméno místnosti v rámci oblasti není unikátní.";
$vocab["area_does_not_exist"]         = "Neexistující oblast:";
$vocab["room_does_not_exist"]         = "Neexistující místnost:";
$vocab["creating_new_area"]           = "Vytvoření nové oblasti:";
$vocab["creating_new_room"]           = "Vytvoření nové místnosti:";
$vocab["could_not_create_area"]       = "Nelze vytvořit oblast";
$vocab["could_not_create_room"]       = "Nelze vytvořit místnost";
$vocab["could_not_find_room"]         = "Nelze nalézt místnost";
$vocab["could_not_import"]            = "Nelze importovat";
$vocab["no_LOCATION"]                 = "VEVENT nebosahuje umístění";
$vocab["invalid_RRULE"]               = "Neplatné RRULE: chybí část FREQ";
$vocab["more_than_one_BYDAY"]         = "MRBS nepodporuje více než jednu hodnotu BYDAY v případě, kdy FREQ=";
$vocab["BYDAY_equals_5"]              = "MRBS nepodporuje BYDAY hodnotu 5";
$vocab["unsupported_FREQ"]            = "MRBS nepodporuje FREQ=";
$vocab["unsupported_COUNT"]           = "COUNT není podporován v MRBS";
$vocab["no_indefinite_repeats"]       = "Neomezené opakování není podporováno v MRBS";
$vocab["events_imported"]             = "události naimportovány";
$vocab["events_not_imported"]         = "události nenaimportovány";

// Used in DataTables
$vocab["show_hide_columns"]  = "Zobrazit / skrýt sloupce";
$vocab["restore_original"]   = "Obnovit původní";

// Entry types
$vocab["type.I"]            = "Interní";
$vocab["type.E"]            = "Externí";

// General
$vocab["fatal_db_error"]     = "Závažná chyba: databáze bohužel není momentálně dostupná.";
$vocab["back"]               = "Zpět";

